@@ -53,12 +53,14 @@ class Template(ABC):
         translation: Translation,
         locale: Locale,
         ascii_only: bool,
+        dec31_as_year: bool,
     ) -> None:
         self.model = model
         self.theme = theme
         self.translation = translation
         self.locale = locale
         self.ascii_only = ascii_only
+        self.dec31_as_year = dec31_as_year
 
     # This is behavior:
     @abstractmethod
@@ -93,10 +95,16 @@ class Template(ABC):
 
     @lru_cache(maxsize=1_000)
     def format_date(self, date: date) -> str:
-        return format_date(date, format=self.theme.datefmt, locale=self.locale)
+        format = self.theme.datefmt.full
+
+        is_last_doy = date.month == date.max.month and date.day == date.max.day
+        if is_last_doy and self.dec31_as_year:
+            format = self.theme.datefmt.year_only
+
+        return format_date(date, format=format, locale=self.locale)
 
     @lru_cache(maxsize=1_000)
-    def date_range(
+    def format_date_range(
         self,
         start: Optional[date],
         end: Optional[date],
@@ -153,12 +161,16 @@ class Template(ABC):
         if (ascii_only := config.ascii_only) is None:
             ascii_only = False
 
+        if (dec31_as_year := config.dec31_as_year) is None:
+            dec31_as_year = False
+
         return template(
             model=model,
             theme=theme,
             translation=translation,
             locale=Locale(language),
             ascii_only=ascii_only,
+            dec31_as_year=dec31_as_year,
         )
 
     @classmethod
@@ -307,7 +319,7 @@ class Sequential(Template):
         yield from horizontal_fill(
             tagline,
             Text(
-                self.date_range(item.startDate, item.endDate),
+                self.format_date_range(item.startDate, item.endDate),
                 style=self.theme.emphasis.weak,
             ),
         )
@@ -369,7 +381,7 @@ class Sequential(Template):
         yield from horizontal_fill(
             Text(item.organization or "", style=self.theme.emphasis.maximum),
             Text(
-                self.date_range(item.startDate, item.endDate),
+                self.format_date_range(item.startDate, item.endDate),
                 style=self.theme.emphasis.weak,
             ),
         )
@@ -413,7 +425,7 @@ class Sequential(Template):
                 ),
             ),
             Text(
-                self.date_range(item.startDate, item.endDate),
+                self.format_date_range(item.startDate, item.endDate),
                 style=self.theme.emphasis.weak,
             ),
         )
@@ -547,7 +559,7 @@ class Sequential(Template):
                 (item.type if item.type else "", self.theme.emphasis.weak),
             ),
             Text(
-                self.date_range(item.startDate, item.endDate),
+                self.format_date_range(item.startDate, item.endDate),
                 style=self.theme.emphasis.weak,
             ),
         )
